<template>
    <section class="games">
        <GameSwitch page="slots" />
        <div class="slots__main">
            <div class="search__container">
                <span>Список слотов</span>
                <input 
                    type="text" 
                    class="search__input" 
                    autocomplete="off" 
                    placeholder="Название игры" 
                    v-model="search" 
                />
                <i class="fas fa-search icon-append" aria-hidden="true"></i>
            </div>
            <div class="spinner-border" v-if="isLoading">
                <span class="sr-only">Loading...</span>
            </div>
            <div class="game" v-for="game in games" @click="openGame(game.game_id)" v-else>
                <img :src="game.preview" />
                <div class="info">
                    <div class="title">{{ game.title }}</div>
                    <div class="title2"><i class="fas fa-play"></i></div>
                    <div class="title3">{{ game.provider }}</div>
                </div>
            </div>
            <div class="page__switch" v-if="games.length !== 0 && !isLoading">
                <button class="page__prev" :class="[page == 1 && 'page__prev--disabled']" @click="page--">‹</button>
                <span class="page__now">{{ page }}</span>
                <button class="page__next" :class="[lastPage && 'page__prev--disabled']" @click="page++">›</button>
            </div>

            <span class="games__not-found" v-if="games.length === 0 && !isLoading">Игры с указанными параметрами не найдены</span>
        </div>
    </section>
</template>

<script>
import GameSwitch from '../../components/GameSwitch'

export default {
    components: {
        GameSwitch,
    },


    data() {
        return {
            games: [],
            isLoading: false,
            page: 1,
            search: '',
            delay: null,
            lastPage: false
        }
    },
    methods: {
        init() {
            this.isLoading = true;

            this.$root.axios.post('/slots/getGames', {
                page: this.page,
                search: this.search
            })
            .then(response => {
                const {data} = response;

                if(data.error) {
                    this.games = [];
                    this.isLoading = false;
                    return notify({
                        theme: 'red',
                        text: data.message
                    });
                }

                this.games = data.games;
                this.isLoading = false;
                this.lastPage = data.lastPage;
            })
            .catch(error => {
                notify({
                    theme: 'red',
                    text: 'Обновите страницу'
                })
            })
        },
        openGame(id) {
            return notify({
                        theme: 'red',
                        text: "Требуется депозит от 1000 руб!"
                    });
        }
    },
    watch: {
        search() {
            clearTimeout(this.delay);
            this.delay = setTimeout(() => {
                this.page = 1;
                this.init()
            }, 750);
        },
        page() {
            this.init()
        }
    },
    mounted() {
        this.init()
    }
}
</script>

<style scoped>
.page__switch {
    display: flex;
    justify-content: center;
    margin-top: 10px
}

.page__switch > button {
    position: relative;
    display: block;
    padding: 0.5rem 0.75rem;
    margin-left: -1px;
    line-height: 1.25;
    color: #007bff;
    background-color: #fff;
    border: 1px solid #dee2e6;
    cursor: pointer;
}

.page__prev--disabled {
    cursor: not-allowed;
    pointer-events: none
}

.page__now {
    padding: 10px;
    color: #4e6588
}

.games__not-found {
    display: block;
    margin: 40px
}

.icon-append {
    position: absolute;
    right: 12px;
    top: 12px;
    opacity: .4;
    z-index: 200;
}

.search__container {
    display: flex;
    position: relative;
    justify-content: space-between;
    align-items: center;
    margin: -10px 10px 20px 10px;
}

.search__container > span {
    font-weight: 500;
    font-size: 18px;
}

.search__input {
    background: #eeecfd;
    padding: 18px 21px;
    border: 1px solid #dcd9f7;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
    -webkit-box-shadow: 0 5px 35px rgb(215 211 236 / 25%);
    box-shadow: 0 5px 35px rgb(215 211 236 / 25%);
    border-radius: 4px;
    font-size: 13px;
    line-height: 15px;
    max-height: 20px;
    max-width: 170px;
    padding-right: 30px;
}

.slots__main {
    padding: 32px 15px;
    background: #fff;
    border-radius: 0 0 8px 8px;
    text-align: center
}

.game:hover .info {
    opacity: 1;
    pointer-events: all
}

.info .title {
    font-weight: 700;
    font-size: 14px;
    padding-top: 20px;
    z-index: 1;
    color: #fff;
    display: flex;
    flex-direction: column
}

.info .title2 {
    z-index: 1;
    color: #fff;
    display: flex;
    font-size: 30px;
    flex-direction: column;
    opacity: .95
}

.info .title3 {
    padding-bottom: 18px;
    z-index: 1;
    color: #fff;
    display: flex;
    flex-direction: column;
    font-weight: 600;
}

.info {
    opacity: 0;
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    flex-direction: column;
    display: flex;
    justify-content: space-between;
    padding: var(--spacing-1);
    pointer-events: none;
    transition: .4s
}

.info:before {
    opacity: .85;
    content: "";
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    background-image: linear-gradient(to bottom,#2c80ff,#1d66ca)
}

.list {
    text-align: center
}

.game img {
    width: 140px;
    height: 187px;
    border-radius: 10px
}

.game {
    margin: 5px;
    border: 0;
    cursor: pointer;
    border-radius: .5rem;
    width: 140px;
    height: 187px;
    transition: 400ms ease;
    overflow: hidden;
    position: relative;
    display: inline-flex;
    justify-content: center;
    align-items: center;
    box-shadow: 0 5px 10px 2px rgb(8 10 12/5%)
}

.game:hover {
    transform: translateY(-4%)
}

.spinner-border {
    display: inline-block;
    width: 2rem;
    height: 2rem;
    vertical-align: text-bottom;
    border: .25em solid currentColor;
    border-right-color: currentcolor;
    border-right-color: transparent;
    border-radius: 50%;
    animation: spinner-border .75s linear infinite;
}

@keyframes spinner-border {
    to {
        transform: rotate(360deg)
    }
}
</style>